# _*_coding     : UTF_8_*_
# Author        :Jie Shen
# CreatTime     :2022/1/17 20:53

class ListNode:
    def __init__(self, val=0, next=None):
        self.val = val
        self.next = next


class BuildTree:

    def __init__(self):
        pass

    def build_by_array(self, arr) -> ListNode:
        if arr is None or len(arr) == 0:
            return None
        head = ListNode(arr[0])
        node = head
        for _ in range(1, len(arr)):
            node.next = ListNode(arr[_])
            node = node.next
        return head


def print_node(head: ListNode):
    print("node:", end="")
    if head is None:
        print(None)
        return
    while head is not None:
        print(head.val, end=",")
        head = head.next
    print()


if __name__ == '__main__':
    arr = [1, 2, 3]
    b = BuildTree().build_by_array(arr)
    print_node(b)



# _*_coding     : UTF_8_*_
# Author        :Jie Shen
# CreatTime     :2022/1/25 10:23
from collections import deque
from typing import List


class TreeNode:
    def __init__(self, val=0, left=None, right=None):
        self.val = val
        self.left = left
        self.right = right


def build_by_order():
    """
    按顺序添加左右孩子
    :return:
    """
    pass


def sortedArrayToBST(nums: List[int]):
    """
    从一个升序数组创建平衡二叉搜索树
    108. 将有序数组转换为二叉搜索树: https://leetcode-cn.com/problems/convert-sorted-array-to-binary-search-tree/
    :param nums: 
    :return: 
    """
    pass


def print_TreeNode(root: TreeNode):
    order = levelOrder(root)
    print(order)


def levelOrder(root: TreeNode) -> List[List[int]]:
    res = []
    q = deque()
    if root is not None:
        q.append(root)
    while q:
        Size = len(q)
        tmp = []
        # 记录这层的所有node
        while Size > 0:
            Size -= 1
            node = q.popleft()
            if node is None:
                tmp.append(None)
                continue
            tmp.append(node.val)
            q.append(node.left)
            q.append(node.right)
            # if node.left is not None:
            #     q.append(node.left)
            # if node.right is not None:
            #     q.append(node.right)
        res.append(tmp)
    return res



# _*_coding     : UTF_8_*_
# Author        :Jie Shen
# CreatTime     :2022/1/25 10:59

import setuptools
from setuptools import find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()
setuptools.setup(
    name='jshen',  # How you named your package folder (foo)
    # packages=['jshen'],  # Chose the same as "name"
    package_dir={"": "src"},
    packages=find_packages("src"),
    include_package_data=True,
    platforms="any",
    version='0.0.11',  # Start with a small number and increase it with every change you make
    license='MIT',  # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description='Tools for leetcode,kaggle...',  # Give a short description about your library
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='J.Shen',  # Type in your name
    author_email='shenjiecn@qq.com',  # Type in your E-Mail
    url='https://github.com/JieShenAI/jshen/',  # Provide either the link to your github or to your website
    # download_url = 'https://github.com/JieShenAI/jshen/Cookie2Dict/archive/master.zip',
    keywords=['TreeNode'],  # Keywords that define your package best
    install_requires=[],
    classifiers=[
        'Development Status :: 3 - Alpha',
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',  # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',  # Again, pick a license
        'Programming Language :: Python :: 3',  # Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)
